@@ -1,8 +1,8 @@
-/* 
+/*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2014 The PHP Group                                |
+   | Copyright (c) 1997-2018 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -12,7 +12,7 @@
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Colin Viebrock <colin@easydns.com>                          |
+   | Authors: Colin Viebrock <colin@viebrock.ca>                          |
    +----------------------------------------------------------------------+
 */
 
@@ -21,6 +21,6 @@
 #ifndef CSS_H
 #define CSS_H
 
-PHPAPI void php_info_print_css(TSRMLS_D);
+PHPAPI void php_info_print_css(void);
 
 #endif
